@@ -5,6 +5,7 @@ from assertman.objects.assertable_int import AssertableInt
 from assertman.objects.assertable_float import AssertableFloat
 from assertman.objects.assertable_datetime import AssertableDatetime
 from assertman.objects.assertable_bool import AssertableBool
+from assertman.objects.assertable_none import AssertableNone
 import datetime
 
 
@@ -23,4 +24,6 @@ def make_assertable_object(arg):
         return AssertableDict(arg)
     elif isinstance(arg, datetime.datetime):
         return AssertableDatetime(arg)
+    elif arg is None:
+        return AssertableNone(arg)
     raise ValueError(f"Для переданнного типа даннных <{type(arg)}> нет маппинга")
\ No newline at end of file
